#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-sphinxcontrib-websupport%{psuffix}
Version:        1.2.7
Release:        1.4
Summary:        Sphinx API for Web Apps
License:        BSD-2-Clause
URL:            https://github.com/sphinx-doc/sphinxcontrib-websupport
Source:         https://files.pythonhosted.org/packages/source/s/sphinxcontrib-websupport/sphinxcontrib_websupport-%{version}.tar.gz
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-docutils
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module Sphinx >= 5.0}
BuildRequires:  %{python_module Whoosh}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sphinxcontrib-websupport >= %{version}}
%endif
%python_subpackages

%description
sphinxcontrib-webuspport provides a Python API to integrate Sphinx
documentation into your Web application.

%prep
%autosetup -p1 -n sphinxcontrib_websupport-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc CHANGES README.rst
%dir %{python_sitelib}/sphinxcontrib/
%{python_sitelib}/sphinxcontrib/websupport
%{python_sitelib}/sphinxcontrib_websupport-%{version}*-info
%endif

%changelog
* Sun Jan 14 2024 Dirk Müller <dmueller@suse.com>
- update to 1.2.7:
  * Fix tests for sqlalchemy 2.
  * Publish a ``whoosh`` extra.
* Thu Sep  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.6:
  * Fix tests for Sphinx 7.1 and below
  * Drop support for Python 3.5, 3.6, 3.7, and 3.8
  * Raise minimum required Sphinx version to 5.0
- drop python-sphinxcontrib-websupport-no-six.patch (upstream)
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Thu Apr  6 2023 pgajdos@suse.com
- do not require six
- added patches
  fix https://github.com/sphinx-doc/sphinxcontrib-websupport/commit/a249f8f962bb4687b780482c6c5a1cc3dc60629f
  + python-sphinxcontrib-websupport-no-six.patch
* Thu Feb 16 2023 Matej Cepl <mcepl@suse.com>
- Remove test dependency on xapian, which has large dependencies
  itself, and it is not required for testing (the test suite can
  skip tests which require it).
- Clean up SPEC file.
* Mon Aug 31 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.4:
  * Import PickleHTMLBuilder from sphinxcontrib-serializinghtml package
* Tue Jul 28 2020 Marketa Calabkova <mcalabkova@suse.com>
- version update to 1.2.3
  * #43: doctreedir argument has been ignored on initialize app
  * Stop to use sphinx.util.pycompat:htmlescape
* Fri Mar 27 2020 pgajdos@suse.com
- version update to 1.2.1
  * #41: templates/searchresults.html is missing in the source tarball
* Mon Mar  2 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.2.0:
  * Drop python2.7 and 3.4 support
* Thu Jun  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to multibuild to fix testing issues
* Fri May 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.2:
  * Fixes for sphinx 2.0
- Enable tests (failing for now)
* Tue Apr 23 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.1.0
  * Add compatibility with Sphinx 1.6. Thanks to Dmitry Shachnev.
  * More minor changes. See CHANGES.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Mar  8 2018 aplanas@suse.com
- Allows Recommends and Suggest in Fedora
* Tue Feb 27 2018 aplanas@suse.com
- Suggests only for SUSE
* Mon Sep 18 2017 toddrme2178@gmail.com
- Created base namespace package based on sphinxcontrib-websupport
  sphinxcontrib-websupport is used since Sphinx depends on it, so
  all other sphinxcontrib packages depend on it indirectly.
  This avoids dependency loops between sphinxcontrib-websupport
  and Sphinx.
* Mon Sep 18 2017 toddrme2178@gmail.com
- Specify files to guarantee namespace package doesn't conflict
  with python(2|3)-Sphinx
* Wed Jun 28 2017 jengelh@inai.de
- Ensure neutrality of description.
* Mon Jun 26 2017 tbechtold@suse.com
- Initial packaging (version 1.0.1)
